Class: Ronin::Scanners::NiktoTask
- Inherits:
-
RProgram::Task
- Object
- RProgram::Task
- Ronin::Scanners::NiktoTask
- Defined in:
- lib/ronin/scanners/nikto/nikto_task.rb
Overview
Nikto options:
- -h
nikto.host
- -config
nikto.config
- -Cgidirs
nikto.cgi_dirs
- -cookies
nikto.print_cookies
- -evasion
nikto.evasion
- -findonly
nikto.evasion
- -Format
nikto.format
- -generic
nikto.full_scan
- -id
nikto.http_auth
- -mutate
nikto.mutate_checks
- -nolookup
nikto.no_lookup
- -output
nikto.output
- -port
nikto.port
- -root
nikto.root
- -ssl
nikto.ssl
- -timeout
nikto.timeout
- -useproxy
nikto.enable_proxy
- -vhost
nikto.vhost
- -Version
nikto.version
- -404
nikto.not_found_message
- -dbcheck
nikto.validate_checks
- -debug
nikto.debug
- -update
nikto.update
- -verbose
nikto.verbose
Instance Method Summary collapse
-
#csv_format! ⇒ Object
Sets the report format to
CVS. -
#directory_self_reference! ⇒ Object
Enable adding self-referencing directories (/./) to the request.
-
#fake_params_to_files! ⇒ Object
Enable fake parameters to files.
-
#html_format! ⇒ Object
Sets the report format to
HTM. -
#premature_url_ending! ⇒ Object
Enable premature URL ending.
-
#prepend_random_strings! ⇒ Object
Enable prepend long random strings to the request.
-
#random_casing! ⇒ Object
Enable random case sensitivity.
-
#random_uri_encoding! ⇒ Object
Enable random URI encoding.
-
#session_splicing! ⇒ Object
Enable session splicing.
-
#tab_request_spacer! ⇒ Object
Enable using a tab character as the request spacer, instead of spaces.
-
#text_format! ⇒ Object
Sets the report format to
TXT. -
#windows_directories! ⇒ Object
Enable use of Windows style directory separators (\</tt> instead of /).
Instance Method Details
#csv_format! ⇒ Object
Sets the report format to CVS.
158 159 160 |
# File 'lib/ronin/scanners/nikto/nikto_task.rb', line 158 def csv_format! self.format = 'CSV' end |
#directory_self_reference! ⇒ Object
Enable adding self-referencing directories (/./) to the request.
75 76 77 78 |
# File 'lib/ronin/scanners/nikto/nikto_task.rb', line 75 def directory_self_reference! self.evasion ||= '' self.evasion << '2' end |
#fake_params_to_files! ⇒ Object
Enable fake parameters to files.
99 100 101 102 |
# File 'lib/ronin/scanners/nikto/nikto_task.rb', line 99 def fake_params_to_files! self.evasion ||= '' self.evasion << '5' end |
#html_format! ⇒ Object
Sets the report format to HTM.
144 145 146 |
# File 'lib/ronin/scanners/nikto/nikto_task.rb', line 144 def html_format! self.format = 'HTM' end |
#premature_url_ending! ⇒ Object
Enable premature URL ending.
83 84 85 86 |
# File 'lib/ronin/scanners/nikto/nikto_task.rb', line 83 def premature_url_ending! self.evasion ||= '' self.evasion << '3' end |
#prepend_random_strings! ⇒ Object
Enable prepend long random strings to the request.
91 92 93 94 |
# File 'lib/ronin/scanners/nikto/nikto_task.rb', line 91 def prepend_random_strings! self.evasion ||= '' self.evasion << '4' end |
#random_casing! ⇒ Object
Enable random case sensitivity.
116 117 118 119 |
# File 'lib/ronin/scanners/nikto/nikto_task.rb', line 116 def random_casing! self.evasion ||= '' self.evasion << '7' end |
#random_uri_encoding! ⇒ Object
Enable random URI encoding.
66 67 68 69 |
# File 'lib/ronin/scanners/nikto/nikto_task.rb', line 66 def random_uri_encoding! self.evasion ||= '' self.evasion << '1' end |
#session_splicing! ⇒ Object
Enable session splicing.
133 134 135 136 |
# File 'lib/ronin/scanners/nikto/nikto_task.rb', line 133 def session_splicing! self.evasion ||= '' self.evasion << '9' end |
#tab_request_spacer! ⇒ Object
Enable using a tab character as the request spacer, instead of spaces.
108 109 110 111 |
# File 'lib/ronin/scanners/nikto/nikto_task.rb', line 108 def tab_request_spacer! self.evasion ||= '' self.evasion << '6' end |
#text_format! ⇒ Object
Sets the report format to TXT.
151 152 153 |
# File 'lib/ronin/scanners/nikto/nikto_task.rb', line 151 def text_format! self.format = 'TXT' end |
#windows_directories! ⇒ Object
Enable use of Windows style directory separators (\</tt> instead of /).
125 126 127 128 |
# File 'lib/ronin/scanners/nikto/nikto_task.rb', line 125 def windows_directories! self.evasion ||= '' self.evasion << '8' end |